# Timesys Test Project (TSTP)

## Introduction

TSTP is a simple collection of test applications, as well as a simple
cross-build system and a framework for running these tests on the target.

## Usage

In the `/usr/tstp` directory on the target, you can run:
```shell
./Test.sh
```
This will run through the test suites.  You can also pass the following
options:
```
 -a     Only run automated tests
 -i     Only run interactive tests
 -s     Run the named suite(s)
 -t     Only run the named test(s)
 -L     Path to save log files
 -N     Do not run any tests (dry run)
 -D     Enable debugging output messages
```

## Configuration

On the target, the primary test configuration files are:
```
/usr/tstp/conf/interactive.conf
/usr/tstp/conf/automated.conf
```

Those are the manifests for the interactive and automated tests,
respectively. These configurations are very simple: they map a command
and parameters to a test name.  For interactive tests, they also provide
the ability to prompt the test engineer before and/or after a test.

To add a new test to the manifest, add a line as described in one of the
following sections.

### Automated Tests
```shell
run_automated "Test name" "Test Command" "Test Parameters"*
```
- Test name:         Human readable test name
- Test command:      Application to be executed for the test
- Test parameters:   Parameters to pass to the application

### Interactive Tests
```shell
run_interactive "Test Name" "Pre-test Prompt" "Post Test Prompt" \
	"Test Command" "Test Command Parameters"*
```
- Pre-test Prompt:   Prompt provided to user prior to the test execution
- Post-test Prompt:  Prompt provided to the user after test execution (optional)
- Test name:         Human readable test name
- Test command:      Application to be executed for the test
- Test parameters:   Parameters to pass to the application

If the post-test prompt is not empty, that message will be followed with a
`y/n/retry` prompt. `y` will mark the test successful, `n` will mark it
as a failure, and `r` will run the test again.

If the post-test prompt is empty, then the pre-test prompt will
halt until a user presses a key to continue, and the return value of the
test command will determine success or failure.

### Other Test Suites

Any number of test suites may be developed and run independently.
Simply create additional configuration files, utilizing the
`run_automated` or `run_interactive` commands.  These may be run
using the `Test.sh` harness.

### Developing Test Suites

Presently, BSP developers and test engineers must create custom
test suites for each system.  This process typically takes an
iterative and incremental approach, starting by installing an image
on the target system that includes `timesys-test-project` with empty
configuration files:

1. Begin running tests by hand, taking note of missing dependencies and
   the parameters required to achieve the desired results.

2. Update the test configuration:

   1. Expand your test manifests with new test invocations.
   2. Add any missing dependencies to the build system.

3. Rebuild, reinstall, and run your new test suites.  Unless you have
   added all required tests (and they pass), go back to step 1.

For more information about this process, see the
[Development Guide](docs/develop.md).

## Implementing New Tests

Currently, the system supports shell scripts and C files.

To add a test, copy the script/source file into the appropriate directory
under target (e.g. `target/audio`).  Then, modify the `.mk` file in that
directory to add the new test file to the manifest.

For scripts, these will be copied to the build directory (and
subsequently the installation directory) when `make` is run.

For C files, these will be compiled and then copied.

## Build Environment

You must set up a proper cross-compilation environment.  Yocto is the
preferred means of using this project, but other environments should
be supported.

Once you have selected and established a build environment, the next
sections describe how to build and install the package.

### Yocto Recipe

The [`meta-timesys-test`][1] layer provides a recipe for building and
installing this project in a Yocto image.

[1]: https://src.timesys.com/timesys/test/meta-timesys-test

That layer provides an overlay recipe template to use in your BSP layer.
The overlay allows the BSP to provide its own test suites and configuration
files, and it disables tests that are not needed for a particular target.

### Yocto SDK

With an installed Yocto SDK, you can run a command like the following to
establish the proper environment:
```shell
source ~/SDK/armv7l/environment-setup-cortexa9hf-vfp-neon-poky-linux-gnueabi
```

### Other Build Environments

There are many other possible build environments that could be used to
build this project.  They key requirements include a cross-compiling
toolchain and suitable headers and libraries.  Presently, the use of
such alternatives is left as an exercise for the reader, but please
consider contributing a patch to document your steps to guide others.

## Building

The `make` command will build everything.

To disable certain tests (or exclude individual data files), you can
pass `TSTP_DISABLED_TESTS` on the command line:
```shell
make TSTP_DISABLED_TESTS="test_adc_imx backing-file"
```

## Installing

To install, you can run:
```shell
make install DESTDIR=/path/to/destination
```
For instance, if you have mounted an SD card root partition to
`/media/rfs`, you can run:
```shell
make install DESTDIR=/media/rfs
```
