# Development Guide for TSTP

This document serves to guide developers through understanding and
extending the Timesys Test Project (TSTP), to permit the tests to be
used in many different board support projects while avoiding any extra
support or maintenance burden for our customers or developers.

## Repositories

The Timesys Test Project exists in the Timesys Gitlab as two separate
repositories.

![TSTP Repositories](tstp-repos.png "TSTP Repositories")

The [timesys-test-project][] repository contains all of the tests, the
test harness, and core configuration.

The [meta-timesys-test][] repository contains a Yocto layer, with a recipe
that can fetch and build TSTP from the other repository.  Usually, this
recipe does not need to be modified directy; rather, an overlay recipe
can be provided in another layer that provides customized configuration
files and settings.

[timesys-test-project]: https://src.timesys.com/timesys/test/timesys-test-project
[meta-timesys-test]: https://src.timesys.com/timesys/test/meta-timesys-test

## Creating Your Test Plans

The first step in using the Timesys Test Project involves coming up with
a complete list of tests to be performed.  This should primarily require
picking a list of tests included in the project.  However, these may not
provide full coverage, and new functionality will be required.  

By creating a test plan, you will see what existing tests can provide
coverage and what areas will require additional test development.  All
planned tests can be sorted into one of the following categories:

- Existing Tests
- Extensible Tests
- Customer Tests

### Existing Tests

If there is an existing/similar test script already available, any
necessary functionality should be added to that test script.  Those
modifications should be made in a manner as to both meet the
requirements of your new project as well as to avoid disrupting existing
use cases.

### Extensible Tests

If you have developed an entirely new test script, you should add it in
as a new part of the testing suite.  These additions should include
documentation of any options that may be required or avaiable to
control/toggle testing behaviors.

### Customer Tests

In the case that a test covers a mechanism that is unlikely to ever be
required by another project (e.g. it covers a customer’s custom
software), that test should not reside in Timesys Test Project.

These sorts of tests should be incorporated separately in a clone of
the TSTP project, specific to the customer that requires them.

## Developing New Tests

Test coverage can never be complete, so new tests will always need to be
created to fill any holes.

### Forking the Test Suite

The TSTP may be extended by creating a fork of the repository.

For internal Timesys work, this fork can exist as a branch in the main
Git repository, with a local clone serving as the main source for the
build process.  Using a branch ensures the merging process (below) will
efficient and relatively painless.

If your test plan requires customer-specific tests, you will need to
clone the TSTP repository into their project to develop those tests.

In either case, the customer project must host a clone of the Timesys
Test Project repository, as that permits their developers to clone and
build the project.  The master repository in `/timesys/test` should be
accessible only to Timesys engineers.

### Writing Tests: Shell Scripts

Many features can be tested using shell scripts, either through `/sysfs`
or by stringing together invocations of existing program binaries that
exist in the system.  For example, many audio tests can be performed by
using the `aplay`, `arecord`, and other utilities provided by the
`alsa-utils` package.

### Writing Tests: C Binaries

Some features can only be accessed at a lower level than possible using
high level scripting languages.  In these cases, you may need to develop
a C program to provide test coverage.

## Merging Tests Upstream

Once your have finished adding new tests to your project's test suite,
the various scripts must be merged back into Timesys Test Project.

## Workflow

![TSTP Workflow](tstp-workflow.png "TSTP Workflow")

