# TSTP Overlays

Timesys Test Project (TSTP) supports the use of "overlay" tests.
This feature permits the build system to merge external tests into the
TSTP source tree, such that they will be built and installed as part of
existing test projects.

## In-tree Overlays

This document explains the in-tree mechanisms for adding new tests,
without modifying any of the existing source files.  This methodology
permits developers to create a branch that contains new tests without
risking future merge conflicts.

These mechanisms also enable out-of-tree build systems to provide
new tests.  Those systems are out of the scope of this document.

### Overlay Structure

A test overlay directory mirrors the structure of the
`timesys-test-project` source tree.  An overlay can be recursively
copied into that source tree, overwriting any existing files.

## Adding Test Suites

Test suites reside in `conf/`.  An overlay should provide the
default `interactive.conf` and `automated.conf` suites.

## Adding a New Test Group

If you want to add tests that do not belong in other test groups,
you can add a new test group.  Start by creating a new directory
to hold your test files.

For example, you might create a `target/customer` directory to include
customer-provided test scripts.

### Adding Makefile Fragment (.mk)

Each test group directory must provide a Makefile fragment to 
specify the test scripts, programs, or data files.  This primary
fragment must have the same base name as the test group directory and
end with the `.mk` suffix.

For our customer example, you would create `target/customer/customer.mk`
and add some initial test boilerplate:

```shell
customer_SCRIPT = customer-test.sh
customer_SIMPLE_C = customer-test.c
customer_DATA = customer.dat

$(eval $(call SETUP_STANDARD_RULES,customer))
```

The last line instantiates the rules and targets required for building
and installing the listed files.  The top-level Makefile automatically
detects and includes this fragment.

## Extending Test Groups

New tests can be added to existing (upstream) test groups.

### Extended Makefile Fragment (.emk)

To include a new test in the build, you need to create (or adjust)
an "extended Makefile fragment".  Like the primary fragment,
an extended fragment must have the same base name as the test group
directory but with the `.emk` suffix.

For example, a new audio test could be added by creating
`target/audio/audio.emk` with a directive to add a test script:

```shell
audio_SCRIPT += cluck_like_a_chicken.sh
```

The primary test group Makefile fragment automatically detects and
includes an extended Makefile fragment.
