# Test Project TODO

This document covers the extended wish list for improvements that might
someday be made to this project.  The existence of items on this list (or
even the list itself) does not guarantee these things will be done, rather
they reflect an ideal state that might someday be attained with sufficient
time and effort.

## Documentation

### In-tree Documentation

- Wrap content to 72 columns
- Add more items to this TODO list
- Write up style rules for:
  - documentation
  - shell scripts
  - C source files

### Test Documentation

- Add block comments that describe:
  - Component under test
  - Coverage of the test(s)
  - Test configuration: environment, arguments, etc.
  - Test dependencies: some tests may assume that other tests already passed
  - Target requirements: some tests will only run on certain targets
  - Software requirements: scripts/programs/packages, versions, etc.
  - Hardware requirements: cabling, remote systems, etc.
  - Interaction requirements
- Document duplication among existing tests
- All comments should be in markdown
- Add top-level doc/ to cover architecture/design/frameworks

### Documentation Tools

- Extract documentation blocks into master document
- Format master document to text/PDF/HTML/etc.

## Build Scripts

- Add `docs` targets to generate documentation
- Embrace the `menuconfig` system for configuring tests and features

## Test Frameworks

- Ensure all scripts work on simple shells (e.g. busybox's ash... not bash!)
- Merge automated/interactive test lists
- Define new test suites: selftest, smoke, full
- Move all variables from config files into their own config file
- Automatically generate source version string (w/ git SHA)
- Make all source files conform to style rules (once defined)

### Data-Driven Testing

Items in this section represent a paradigm shift, so they mostly likely
require major implementation changes that will break compatibility. Thus,
they most likely would be added as part of a major upgrade branch
(i.e. version 2.0).

- Investigate data-driven test harnesses
- Automatically generate test lists
- Resume tests after a reboot (e.g. watchdog reset)
- Run tests in random order
- Implement inter-test dependencies: if t2 assumes t1 passes, run t1 before t2

### Script Library

### C Library

### Test Results

- Add/improve library routines to produce consistent output from tests
- Produce a composite report (consisting of all log results)
- Capture prompt/input for interactive tests?
- Detect/identify regressions by comparing successive test runs
- Capture source version, date of run, etc. in output

## Test Programs

- Use `set -e` to catch any intermediate/unexpected errors
- Use quotes around arguments that may be empty
- Document using header comment block (see Test Documentation above)
- Use `local` for function-scoped variables
- Use more functions to encapsulate script tasks
- Implement `help` function to extract/display header comment
- Use `usage` function to provide test usage
- Use `parse_opts` to handle test options and arguments
- Normalize test script/program names (e.g. `test_${GROUP}_${TEST}${EXT}`)
- Normalize device arguments (e.g. watchdog0 vs. /dev/watchdog0)
- Convert test requirement documentation (see above) into executable assertions
- Eliminate test program arguments in favor of configuration files

### New Tests

- review branches/forks to cherry pick reusable tests into `master`
- `depcheck`: verify given list of commands are included/omitted
- `memory`: check expected memory contents (e.g. registers) via `devmem`
- `shell`: verify `/bin/sh` includes sufficient features to run test scripts
- `sysinfo`: capture all hardware/software system information for later review

### Audio

### Backlight

### Buzzer

### CPU

### EEPROM

### Framebuffer (fb)

### Filesystem (fs)

- `test_fs.sh`: Add `DRY_RUN` support

### gpiolib

- `test_gpio_sysfs.sh`: Add `DRY_RUN` support

### graphics

- `vivante-graphics-test.sh`: split test script into parts?

### GStreamer (gst-fsl)

- `test_pipelines.sh`: split test script?
- `test_pipelines.sh`: add mnemonic modes to replace numeric modes?

### hwmon

- `test_tempsensor.sh`: probably does not work with all temp sensor combos

### i2c

### iio

### i.MX: ADC

- `test_adc`: automatically disable build on non-imx targets

### i.MX: Display

- Merge with Framebuffer (fb) tests?

### Keyboard

- `button-test.c`: permit test to exit without interrupt?

### LEDs

### MMC

- Merge MMC/SD scripts

### MTD

- `flash.sh`: Add `DRY_RUN` support

### Network

### PCIe

### PMIC

### RTC

- `rtctest`: split test into parts
- `test_rtc.sh`: Add `DRY_RUN` support

### SPI

### TI: UPP

- `test_loopback`: test is incomplete and unlikely to be useful as-is

### Touchscreen

### UART

### USB

- Merge `usb` and `usb_gpio` scripts
- `usb`/`usb_gpio`: make drive device configurable
- `backing-file`: can we generate backing-file dynamically (and remove)?
- `usb_gadget_test.sh`: remove unused `check_sshpass_installed` function

### Watchdog

- `watchdog-test`: doesn't disable watchdog on exit (must be run again with -d)
- Merge `watchdog-simple.c` into `watchdog-test.c`
- `watchdog-test.sh`: add `DRY_RUN` support
