#!/bin/sh -e

source "@TSTPLIB@"

load_libraries files

write_verify_test(){
	BS=1k
	COUNT=$(shuf -i 1-$MAX_SIZE -n 1)

	echo "+++ Generating random data"
	dd if=/dev/urandom of=$INFILE bs=$BS count=$COUNT

	echo "+++ Writing random data to $MOUNT_POINT"
	cp $INFILE $OUTFILE
	sync
	echo 3 > /proc/sys/vm/drop_caches 

	if files_equal "$INFILE" "$OUTFILE"; then
		echo "+++ Files match"
	else
		echo "+++ Data mismatch"
		exit 1
	fi
}

opt_usage_r() { echo "Number of seconds to run the test"; }
opt_parse_r() { RUN_DURATION=$1; }

opt_usage_t() { echo "Type of test, either 'device' or 'mount'"; }
opt_parse_t() { HANDLE_TYPE=$1; }

opt_usage_f() { echo "Path to mount point or test folder"; }
opt_parse_f() { FILE_PATH=$1; }

FS_TYPE=
opt_usage_T() { echo "Type of filesystem of 'device' to mount"; }
opt_parse_T() { FS_TYPE=$1; }

MAX_SIZE=
opt_usage_S() { echo "Maximum number of 1K blocks to use"; }
opt_parse_S() { MAX_SIZE=$1; }

LAST_MOUNTED_DEV=false
opt_usage_l() { echo "Perform test on last mounted device"; }
opt_parse_l() { LAST_MOUNTED_DEV=true; }

args_help() {
	cat <<EOF
Examples:
  $TEST -t device -f /dev/mmcblk0p1 -r 10
  $TEST -t device -f /dev/mtdblock5 -T jffs2 -S 2048
  $TEST -t mount -f /run/media/sdc
  $TEST -l
EOF
}

parse_opts "r:t:f:T:S:l" "$@"

if [ ! -z "$RUN_DURATION" ]; then
	START_TIME=$(date +%s)
	END_TIME=$(($START_TIME + $RUN_DURATION))
fi

umount_device() {
	rm -f $OUTFILE
	umount $MOUNT_POINT
}

mount_device() {
	local MOUNT_TYPE
	[ -z "$FS_TYPE" ] || MOUNT_TYPE="-t $FS_TYPE"
	mktempfile MOUNT_POINT -d
	mount $MOUNT_TYPE "$FILE_PATH" "$MOUNT_POINT"
	cleanup_add umount_device
	sleep 2
}

if $LAST_MOUNTED_DEV; then
	MOUNT_POINT=$(mount |tail -1 | awk '{ print $3 }')
elif [ "$HANDLE_TYPE" == "mount" ]; then
	MOUNT_POINT=$FILE_PATH	
elif [ "$HANDLE_TYPE" == "device" ]; then
	MOUNT_POINT=$(mount |grep $FILE_PATH | awk '{ print $3 }')
	[ "$MOUNT_POINT" ] || mount_device
elif [ -z "$HANDLE_TYPE" ]; then
	usage "test type (-t) was not specified"
else
	usage "$HANDLE_TYPE: invalid test type"
fi

[ "$MOUNT_POINT" ] || error "no mount point specified"
[ -d "$MOUNT_POINT" ] || error "$MOUNT_POINT: not a directory"

mktempfile INFILE
mktempfile OUTFILE -p $MOUNT_POINT

[ "$MAX_SIZE" ] || MAX_SIZE=$(df | grep $MOUNT_POINT | awk '{ print $4 }')
[ "$MAX_SIZE" ] || MAX_SIZE=10000
[ $MAX_SIZE -lt 10000 ] || MAX_SIZE=10000

while true; do 
	write_verify_test
	if [ ! -z "$END_TIME" ]; then
		CURRENT_TIME=$(date +%s)
		if [ "$CURRENT_TIME" -gt "$END_TIME" ]; then
			exit 0
		fi
	else
		exit 0
	fi
done
