#!/bin/sh

# This script reads accelerometer input values using evtest utility and the sysfs interface to confirm accelerometer functionality.

opt_args=$1
device_name=$(cat /sys/devices/virtual/input/input${opt_args}/name)
if [ ! "$device_name" ]; then
   echo "No Virtual input device present."
   echo "Accelerometer: FAIL"
   exit 1
fi
echo "Accelerometer: $device_name"

ENABLE_PATH="/sys/devices/virtual/input/input${opt_args}/enable"

if [ ! -f "${ENABLE_PATH}" ]; then
	ENABLE_PATH="/sys/devices/virtual/misc/${device_name}/enable"
	if [ ! -f "${ENABLE_PATH}" ]; then
		echo "Accelerometer: Unable to locate enable path"
	fi
fi

accel_status=$(cat ${ENABLE_PATH})
if [ $accel_status != 1 ]; then
        echo "Enabling the accelerometer"
        echo 1 > ${ENABLE_PATH}
        sleep 1
fi

evtest /dev/input/event${opt_args} | tee accel_log.txt &

cat accel_log.txt

sleep 1
if grep -q "Event: time" "accel_log.txt" ; then
        echo "Accelerometer: PASS"
else
        echo "No event captured"
        echo "Accelerometer: FAIL"
fi

killall evtest


echo "Disabling the accelerometer"
echo 0 > ${ENABLE_PATH}