#!/bin/sh

set -e

source "@TSTPLIB@"

LEDDIR=/sys/class/leds

LEDS=`ls $LEDDIR`
RATE=1
COUNT=10

# ALLTEST toggles all LEDs
ALLTEST=false

toggle_led()
{
	local LEDNAME=$1
	local LEDFILE=$LEDDIR/$LEDNAME
	local MAX_BRIGHTNESS

	MAX_BRIGHTNESS=`cat $LEDFILE/max_brightness`
	if [[ `cat $LEDFILE/brightness` -eq $MAX_BRIGHTNESS ]]; then
		debug "echo 0 > $LEDFILE/brightness"
		echo 0 > $LEDFILE/brightness
	else
		debug "echo $MAX_BRIGHTNESS > $LEDFILE/brightness"
		echo $MAX_BRIGHTNESS > $LEDFILE/brightness
	fi
}

main() {
	local i LED
	# If LED were given (and -a was not specified), toggle only those
	if ! $ALLTEST && [ "$*" ]; then
		LEDS=$@
	fi
	for i in $(seq 1 $COUNT); do
		for LED in $LEDS; do
			toggle_led $LED
		done
		debug "sleep $RATE"
		sleep $RATE
	done
}


opt_usage_l() { echo "List LEDs on the system"; }
opt_parse_l() {
	local count LED
	count=$(echo $LEDS | wc -w)
	echo "LEDs available: $count"
	for LED in $LEDS; do
		echo "  $LED"
	done
	exit 0
}

opt_usage_r() { echo "Blink rate (in seconds) (Default 1)"; }
opt_parse_r() { RATE=$1; }

opt_usage_c() { echo "Number of repetitions (Default 10)"; }
opt_parse_c() { COUNT=$1; }

opt_usage_a() { echo "Blink all the LEDS"; }
opt_parse_a() { ALLTEST=true; }

args_usage() { echo "[LED]"; }
args_help() {
	local led
	led=$(echo $LEDS | awk '{print $1}')
	cat <<EOF
Examples:
	$TEST $led
EOF
}
args_parse() { main "$@"; }

parse_opts "r:c:al" "$@"
