#!/bin/sh
# deps.sh: dependency checking helpers

# find a dependency checking mechanism
if type command >/dev/null 2>&1; then
	DEP_CHECK_PROGRAM="command -v"
elif which which 2>&1 | grep built-in >/dev/null; then
	DEP_CHECK_PROGRAM="which"
elif [ -f /usr/bin/which -o -f /bin/which ]; then
	DEP_CHECK_PROGRAM=$(which which)
else
	error "missing 'which' command and 'command' built-in"
fi

dep_check_program() {
	debug "Searching for '$1'..."
	$DEP_CHECK_PROGRAM "$1"
}

dep_check_alternatives() {
	local var=$1
	shift

	debug "Searching for $var alternatives..."
	for alt in "$@"; do
		path=$(dep_check_program "$alt" || true)
		if [ "$path" ]; then
			debug "$var: found $path"
			eval $var=$path
			return
		fi
	done
	error "$var: no alternatives found among $*"
}

dep_check_programs() {
	local pgm
	for pgm in "$@"; do
		dep_check_program "$pgm" >/dev/null
	done
}
