#!/bin/sh
# files.sh: shared helpers for file testing and manipulation

dep_check_programs awk md5sum mktemp

# compares contents of two files using md5sum
files_equal() {
	local a=$1
	local b=$2

	a_sum=$(md5sum "$a" | awk '{print $1}')
	b_sum=$(md5sum "$b" | awk '{print $1}')

	[ "$a_sum" = "$b_sum" ]
}

#####
# Temporary files

# list of temporary files that will be removed when the script exits
TEMPFILE_LIST=""

# creates a temporary file and schedules it for cleanup
# $1 - name of variable to receive filename
# $@ - additional options to pass to `mktemp` (e.g. `-p <dir>`)
mktempfile() {
	local var=$1
	local name
	shift
	name=$(mktemp "$@")
	list_append TEMPFILE_LIST "$name"
	eval "$var=\$name"
}

# creates multiple temporary files that will be scheduled for cleanup
# $@ - names of variables to receive filenames
mktempfiles() {
	list_for_each mktempfile "$@"
}

cleanup_tempfiles() {
	[ -z "$TEMPFILE_LIST" ] || rm -rf $TEMPFILE_LIST
}

cleanup_add cleanup_tempfiles
