#!/bin/sh
# opts.sh: option parsing helpers

BUILTIN_OPTS="NDh"
TEST_OPTS=

opt_usage_N() { echo "Do not run any tests (dry run)"; }
opt_parse_N() { DRY_RUN=true; }

opt_usage_D() { echo "Enable debugging output messages"; }
opt_parse_D() { DEBUG=true; }

opt_usage_h() { echo "Display command usage"; }
opt_parse_h() { usage; }

usage() {
	local opts
	local o f
	[ -z "$*" ] || echo "$TEST: error: $*" >&2

	opts=$(echo $TEST_OPTS | sed -e 's,:, <arg>] [-,g')
	echo -n "usage: $TEST [-$opts] "
	! is_function args_usage || echo -n $(args_usage)
	echo

	[ -z "$TEST_OPTS" ] || echo "Options:"
	for o in $(echo $TEST_OPTS | grep -o .); do
		f="opt_usage_$o"
		is_function "$f" || continue
		echo -n "  -$o:  "
		$f
	done
	! is_function args_help || args_help
	exit 1
}

parse_opts() {
	local OPTS="${1}${BUILTIN_OPTS}"
	TEST_OPTS=$OPTS
	local OPTIND=1
	local o f
	shift
	while getopts "${OPTS}" o "$@"; do
		[ "$o" != '?' ] || usage
		f="opt_parse_$o"
		if is_function "$f"; then
			$f "$OPTARG"
		else
			usage "option -$o not handled"
		fi
	done
	shift $((OPTIND - 1))

	# if test script provided args_parse function, process remaining args
	! is_function args_parse || args_parse "$@"
}
