#!/bin/sh
# iperf.sh: common helper functions used iperf tests.


check_connection() {
	echo "Checking Connectivity with $IPADDR"
	run_ssh $USER@$IPADDR true \
		|| error "No connectivity with $IPADDR"
}

killProgram(){
	run_ssh $USER@$IPADDR /bin/bash << EOF
pid=\$(cat $TMP_PID)
kill \$pid
rm $TMP_PID
EOF
	rm $TMP_PID
}

Run_iperf3_on_Remote(){
	echo "Run iperf3 on server $IPADDR"
	touch $TMP_PID
	run_ssh $USER@$IPADDR /bin/bash << EOF
	echo "login to remote machine successful"
	if [ -e $TMP_PID ] && [ -d /proc/\$(cat $TMP_PID) ]; then
		echo "ERROR: THERE IS ALREADY A IPERF3 JOB RUNNING. KINDLY WAIT FOR OTHER IPERF3 JOB TO COMPLETE AND THEN RESUBMIT THIS JOB."
		exit 1
	fi
	if [ -e /bin/iperf3 ] || [ -e /usr/bin/iperf3 ] || ( which iperf3 > /dev/null); then
		nohup iperf3 -s > /dev/null 2>&1 & echo \$! > $TMP_PID
		pid=\$(cat $TMP_PID)
		echo "iperf3 started on server with pid: \$pid"
	else
		echo "iperf3 is not installed on remote machine."
		exit 1
	fi
EOF
}

Run_iperf3_on_DUT(){
	echo "Run iperf3 on DUT"
	echo "" > iperf_result.log
	run iperf3 -c $IPADDR --get-server-output -V | tee -a iperf_result.log
	sleep 3
	killProgram
}