#!/bin/sh

source "@TSTPLIB@"

dep_check_programs ip candump

# Sets up can device and performs a BUS dump. Then checks if data
# sent by another CAN node can be read. Requires at least 2 nodes.

usage(){
	cat <<EOF
$TEST {INTERFACE} {BITRATE} {ADDR} {DATA}"
where INTERFACE  - CAN network device"
      BITRATE    - Bitrate of CAN bus under test"
      ADDR       - Address other node is sending data to"
      DATA       - Expected data sent by other CAN node"

Example: ./test_can_dump.sh can0 1000000 123 1122334455"
EOF
	exit 1
}
# Make less than 4
if [ "$#" -lt 4 ] ; then
	usage
fi

DEVICE=$1
BITRATE=$2
ADDR=$3
DATA=$4

ip link set "$DEVICE" up type can bitrate "$BITRATE" > /dev/null 2>&1
echo "Run cansend command now!"
candump "$DEVICE" -n 6 > CAN.log
cat CAN.log

ip link set "$DEVICE" down type can

FORMATTED_DATA="$(echo $DATA | sed 's/.\{2\}/&\\s/g' | sed 's/..$//')"
echo "FORMATTED_DATA: $FORMATTED_DATA"
DATA_REGEX="${DEVICE}\s*${ADDR}\s*\[.*\]\s*${FORMATTED_DATA}"
echo "DATA_REGEX: $DATA_REGEX"

if ! grep -q "$DATA_REGEX" CAN.log; then
	echo "Data not found in dump, CAN is broken!"
	rm CAN.log
	exit 1
else
	echo "Data found in dump, CAN is working!"
	rm CAN.log
	exit 0
fi
