#!/bin/sh -e

source "@TSTPLIB@"

load_libraries ssh net/iperf

USE_DHCP=true

dep_check_programs udhcpc

# This script tests ethernet functionality by ssh to the remote server and it perform the test using ping and iperf utility. It also executes udhcpc to obtain ip for currently running target.

trap "exit 1" TERM
TMP_PID="/tmp/pid"

check_ethernet() {
	dmesg | grep ethernet | grep -q registered && return

	dep_check_programs lspci
	lspci | grep -q Ethernet
}

main(){
	check_ethernet || error "Ethernet is not ready"
	! $USE_DHCP || run udhcpc \
		|| error "udhcpc failed to obtain an IP address"
	check_connection
	[ "$IPERF" = "Y" ] || return 0

	echo "PREREQUISITE: Kindly make sure iperf3 is installed at remote machine as well."
	sleep 2
	dep_check_programs iperf3
	Run_iperf3_on_Remote && Run_iperf3_on_DUT || \
		error "iPerf3 test was not done. If needed pass the argument 'Y' for IPERF in the conf."
} 

opt_parse_D() { USE_DHCP=false; }
opt_usage_D() { echo "Do not run DHCP client at startup"; }
opt_parse_A() { IPADDR=$OPTARG; }
opt_usage_A() { echo "Remote machine IP address"; }
opt_parse_U() { USER=$OPTARG; }
opt_usage_U() { echo "Remote machine user name"; }
opt_parse_P() { PASSWD=$OPTARG; }
opt_usage_P() { echo "Remote machine password"; }
opt_parse_E() { info "iperf testing enabled"; IPERF=Y; }
opt_usage_E() { echo "Enable iPerf3 test"; }

parse_opts "A:U:P:E" "$@"
[ "$IPADDR" -a "$USER" ] || usage
main
