#!/bin/sh -e

source "@TSTPLIB@"

load_libraries ssh net/iperf

trap "exit 1" TERM

# This script tests WiFi functionality by ssh to the remote server and it perform the test using ping and iperf utility.
# It also executes udhcpc to obtain ip for currently running target.

dep_check_programs udhcpc ssh sshpass iperf3 killall wpa_passphrase wpa_supplicant

TMP_PID="/tmp/pid"
USE_DHCP=true

check_WiFi(){
   cat /proc/net/dev | cut -d':' -f1 | grep wlan
}

connect_WiFi(){
    killall wpa_supplicant || echo "continue..."
    wpa_passphrase ${NETWORK} ${PASSKEY} > /tmp/wpa.conf
    wpa_supplicant -D ${DRIVERTYPE} -c/tmp/wpa.conf -i${INTERFACE} -B
}

main () {
	check_WiFi || error "WiFi is not ready"
	connect_WiFi
	! $USE_DHCP || run udhcpc udhcpc -i $INTERFACE -t 5 -n \
		|| error "udhcpc failed to obtain an IP address"
	check_connection

	[ "$IPERF" = "Y" ] || return 0

	echo "PREREQUISITE: Kindly make sure iperf3 is installed at remote machine as well."
	sleep 2
	Run_iperf3_on_Remote &&	Run_iperf3_on_DUT || \
		error "iPerf3 test was not done. If needed pass the argument 'Y' for IPERF in the conf."
}

opt_parse_D() { USE_DHCP=false; }
opt_usage_D() { echo "Do not run DHCP client at startup"; }
opt_parse_A() { IPADDR=$OPTARG; }
opt_usage_A() { echo "Remote machine IP address"; }
opt_parse_U() { USER=$OPTARG; }
opt_usage_U() { echo "Remote machine user name"; }
opt_parse_P() { PASSWD=$OPTARG; }
opt_usage_P() { echo "Remote machine password"; }
opt_parse_E() { info "iperf testing enabled"; IPERF=Y; }
opt_usage_E() { echo "Enable iPerf3 test"; }
opt_parse_I() { INTERFACE=$OPTARG; }
opt_usage_I() { echo "Wifi interface"; }
opt_parse_T() { DRIVERTYPE=$OPTARG; }
opt_usage_T() { echo "Wifi driver type e.g. nl80211"; }
opt_parse_S() { NETWORK=$OPTARG; }
opt_usage_S() { echo "Wifi SSID"; }
opt_parse_K() { PASSKEY=$OPTARG; }
opt_usage_K() { echo "Wifi pass to the SSID"; }


parse_opts "A:U:P:E:I:T:S:K:" "$@"
[ "$IPADDR" -a "$USER" ] || usage
main

