#!/bin/sh

source "@TSTPLIB@"

dep_check_programs fdisk dd awk rev md5sum mount umount

# This script detects the USB device and mounts the device to copy the files for performing the md5sum check to confirm the USB functionality.

BS=1k
COUNT=500
USBDEV=${1-sda}
USBPART="/dev/${USBDEV}1"

checkDetect(){
	if [ -e "$USBPART" ]; then
		echo "USB device is connected"
		mountDevice
	else
		error "No USB detected."
	fi
}

mountDevice(){
	mountPoint="/mnt"
	mounted=$(df | grep "$USBPART")
	if [ "$mounted" == ""  ]; then
		mount "$USBPART" $mountPoint
	else
		mountPoint=$(echo $mounted | rev | cut -d' ' -f1 | rev)
	fi
	generateData $mountPoint
}

generateData(){
	mountPoint=$1
	INFILE=/tmp/input.dat
	OUTFILE=$mountPoint/output.dat
	echo "+++ Generating random data"
	dd if=/dev/urandom of=$INFILE bs=$BS count=$COUNT
	echo "+++ Writing random data to $mountPoint"
	cp $INFILE $OUTFILE
	sync
	checkData $1
}

checkData(){
	mountPoint=$1

	echo "+++ Reading data from $mountPoint"
	MD5IN=$(md5sum $INFILE | awk '{print $1}')
	MD5OUT=$(md5sum $OUTFILE | awk '{print $1}')

	if [[ "$MD5IN" == "$MD5OUT" ]]; then
		echo "+++ Files match"
		echo "USB: PASS"
		clearall
		exit 0
	else
		echo "+++ Data mismatch"
		echo "USB: FAIL"
		clearall
		exit 1
	fi
}

clearall(){
	umount $mountPoint
}

checkDetect

