#!/bin/sh

# This script is what is fed through ssh to the remote testing host for testing USB OTG

TESTCASE=$1
PASSWD=$2

echo "login to remote machine successful"

if [ $TESTCASE == "g_ether" ]; then
	if grep -q Raspbian /usr/lib/os-release; then
		interface=$( dmesg | egrep "cdc_(subset|ether)\s" | tail -1 | egrep -o 'usb[0-9]+' )
	elif grep -q Ubuntu /usr/lib/os-release; then
		interface=$( dmesg | egrep "cdc_(subset|ether)\s" | tail -1 | awk '{print $4}' | sed 's/.$//' )
	else
		echo "USB Gadget Ether: FAIL unsupported testing host distro"
		exit 1
	fi

	if [ -z "$interface" ]; then
		echo "USB Gadget Ether: FAIL interface not found"
		exit 1
	fi
	echo $PASSWD | sudo -S ifconfig $interface 10.0.1.1 netmask 255.255.255.0
	if [ $? -ne 0 ]; then
		echo "USB Gadget Ether: FAIL couldn't bring up interface $interface"
		exit 1
	fi
	ping -c2 -I $interface 10.0.1.2
	if [ $? -eq 0 ]; then
		echo "USB Gadget Ether: PASS"
		exit 0
	else
		echo "USB Gadget Ether: FAIL couldn't ping from remote"
		exit 1
	fi
elif [ $TESTCASE == "g_serial" ]; then
	ls -l /dev/ttyACM0
	if [ $? -eq 0 ]; then
		echo "Manually Transfer Data between Target (ttyGS0) and Host (ttyACM0)"
		echo "USB Gadget Serial: PASS"
		exit 0
	else
		echo "USB Gadget Serial: FAIL"
		exit 1
   fi
elif [ $TESTCASE == "g_mass_storage" ]; then
	echo "Check if mass storage device is visible"
	dmg_log=$(dmesg | tail -40 | grep imx-dms-ba16 | grep usb)
	if [ $dmg_log != "" ]; then
		echo "USB Gadget Mass Storage: PASS"
	else
		echo "USB Gadget Mass Storage: FAIL"
	fi
fi
