#!/bin/sh

source "@TSTPLIB@"

# dependencies depend on parameters, but this triggers build-time warnings
#dep_check_programs modprobe rmmod insmod dd mkfs.msdos
#dep_check_programs ping ssh sshpass nc ifconfig

# This script helps to test the usb emulation of ethernet, mass storage and serial using g_ether, g_mass_storage and g_serial drivers respectively.

echo "Make sure micro-usb cable is connected with client machine."
echo ""
sleep 2

modulePath=/lib/modules/`uname -r`/kernel/drivers/usb/gadget/legacy

usage(){
	echo "usb-gadget.sh -A '{IPADDR}' -U '{USERNAME}' -P '{PASSWORD}' -T '{TESTCASE}'"
	echo "where IPADDR     - Remote machine IP Address"
	echo "      USERNAME   - Remote machine Username"
	echo "      PASSWORD   - Remote machine Password corresponding to username provided"
	echo "      TESTCASE   - USB Gadget Module name which needs to be tested {g_ether/ g_serial/ g_mass_storage}"
	echo "      Help       - Show this message and quit"
	exit 1
}

checkConnectivity(){
	echo "Checking Connectivity with $IPADDR"
	ping $IPADDR -c1 2>&1 >/dev/null
	if [ $? -ne 0 ]; then
		echo "No connectivity with $IPADDR"
		exit 1
	else
		echo "Ping test PASSED"
	fi
}

valid_ip(){
	if expr "$IPADDR" : '[0-9][0-9]*\.[0-9][0-9]*\.[0-9][0-9]*\.[0-9][0-9]*$' >/dev/null; then
		for quad in 2 3; do
			if [ $(echo "$IPADDR" | cut -d. -f$quad) -gt 255 ]; then
				echo "fail ($IPADDR)"
				exit 1
				kill -s TERM $TOP_PID
			fi
		done
		if [ $(echo "$IPADDR" | cut -d. -f4) -gt 254 ]; then
			echo "fail ($IPADDR)"
			exit 1
			kill -s TERM $TOP_PID
		fi
		if [ $(echo "$IPADDR" | cut -d. -f1) -gt 254  ] && [ $(echo "$IPADDR" | cut -d. -f1) -lt 1  ]; then
			echo "fail ($IPADDR)"
			exit 1
			kill -s TERM $TOP_PID
		fi
		#echo "success ($IPADDR)"
		udhcpc -i eth0
		checkConnectivity
	else
		echo "fail ($IPADDR)"
		kill -s TERM $TOP_PID
		exit 1
	fi
}

check_sshpass_installed(){
	if ( which sshpass > /dev/null 2>&1 ); then
		return 0
	else
		echo "sshpass not installed."
		kill -s TERM $TOP_PID
		exit 1
	fi
}

check_package_installed(){
	pack=$1
	if ( which $pack > /dev/null 2>&1 ); then
		return 0
	else
		echo "$pack is not installed."
		exit 1
		kill -s TERM $TOP_PID
	fi
}

unloadModule(){
	module=$1
	if [ "$module" == "all" ]; then
		modprobe -r g_ether
		modprobe -r g_mass_storage
		rmmod $modulePath/g_mass_storage.ko
		modprobe -r g_serial
	elif [ "$module" == "g_mass_storage" ]; then
		rmmod $modulePath/$module.ko
	else
		echo "Unload the module $module"
		modprobe -r $module
	fi
}

remoteSiteExecution(){
	if ( check_package_installed ssh ); then
		if ( check_package_installed sshpass );then
			nc $IPADDR 22 &
			if [ $? -eq 0 ]; then
				echo "Creating usb interface at remote site..."
				export SSHPASS=$PASSWD
				sshpass -e ssh -o "StrictHostKeyChecking no" $USER@$IPADDR 'bash -s' < ./bin/usb/usb_gadget_remote.sh $TESTCASE $PASSWD
				RESULT=$?
				unloadModule $TESTCASE
				exit $RESULT
			else
				echo "sshpass is not installed"
				unloadModule $TESTCASE
				exit 1
			fi
		fi
	fi
}

load_module(){
	module=$1
	echo "Load the module $module"
	if [ $? -eq 0 ]; then
		if [ $module == "g_ether" ]; then
			modprobe $module
			sleep 1
			ifconfig usb0 10.0.1.2 netmask 255.255.255.0
			remoteSiteExecution
		elif [ $module == "g_serial" ]; then
			modprobe $module
			ls -l /dev/ttyGS0
			remoteSiteExecution
		elif [ $module == "g_mass_storage" ]; then
			dd if=/dev/zero of=testfile bs=1M count=100
			mkfs.msdos testfile
			insmod $modulePath/$module.ko file=testfile
			remoteSiteExecution
		else
			echo "Incorrect Module provided. Please select out of the provided testcases as module."
			echo "USB_Gadget: FAIL"
			exit 1
		fi
	else
		echo "$module Module load failed"
		echo "USB Gadget: FAIL"
		exit 1
	fi
}

while getopts "A:U:P:T:h" arg; do
   case "$arg" in
	 A)
		#echo ${OPTARG}
		IPADDR="${OPTARG}"
		;;
	 U)
		#echo ${OPTARG}
		USER="${OPTARG}"
		;;
	 P)
		#echo ${OPTARG}
		PASSWD="${OPTARG}"
		;;
	 T)
		#echo ${OPTARG}
		TESTCASE="${OPTARG}"
		;;
	 h)
		usage
		;;
	 *)
		usage
		;;
  esac
done

if [ $# -eq 0 ]; then
	echo "TESTCASE is a mandatory argument"
	usage
	exit 1
elif [ $# -eq 1 ]; then
	setDefault
fi

main(){
	unloadModule all
	valid_ip
	load_module $TESTCASE
	if [ $? != 0 ]; then
		echo "USB Gadget: FAIL"
		exit 1
	fi
}

main
