#!/bin/sh

# This script is used for gpio controlled USB devices. The script enables the given gpio pin and detects the USB device and mounts the device to copy the files for performing the md5sum check to confirm the USB functionality.

BS=1k
COUNT=500

usage(){
    echo "USB.sh -G '{GPIO_CTRL}'"
    echo "      USB GPIO CONTROL - Controls USB ON/OFF using GPIO"
    echo "      Help       - Show this message and quit"
    exit 1
}

while getopts "G:h" arg; do
   case "$arg" in
     G)
        #echo ${OPTARG}
        GPIO_CTRL="${OPTARG}"
        ;;
     h)
        usage
        ;;
  esac
done

gpioctrl(){
GPIODIR=/sys/class/gpio/gpio$1
if [ ! -e "$GPIODIR" ]
then
        echo "Exporting GPIO"
        echo $1 > /sys/class/gpio/export
fi
echo out > $GPIODIR/direction
echo 1 > $GPIODIR/value
}

checkDetect(){
   fdisk_log=$(fdisk -l | grep sda)
   if [ "$fdisk_log" ]; then
       echo "USB device is connected"
       mountDevice
   else
       echo "No USB detected. Insert a USB device and Hit Enter once done: "
       read input
       checkDetect
   fi
}

mountDevice(){
   mountPoint="/mnt"
   mounted=$(df | grep "/dev/sda1")
   if [ "$mounted" == ""  ]; then
       mount /dev/sda1 $mountPoint
   else
       mountPoint=$(echo $mounted | rev | cut -d' ' -f1 | rev)
   fi
   generateData $mountPoint
}

generateData(){
	mountPoint=$1
	INFILE=/tmp/input.dat
 	OUTFILE=$mountPoint/output.dat
	echo "+++ Generating random data"
	dd if=/dev/urandom of=$INFILE bs=$BS count=$COUNT
	echo "+++ Writing random data to $mountPoint"
	cp $INFILE $OUTFILE
	sync
	checkData $1
}

checkData(){
   mountPoint=$1

   echo "+++ Reading data from $mountPoint"
   MD5IN=$(md5sum $INFILE | awk '{print $1}')
   MD5OUT=$(md5sum $OUTFILE | awk '{print $1}')

   if [[ "$MD5IN" == "$MD5OUT" ]]; then
	   echo "+++ Files match"
	   echo "USB: PASS"
	   exit 0
   else
	   echo "+++ Data mismatch"
	   echo "USB: FAIL"
	   exit 1
   fi
   clearall
}

clearall(){
   umount $mountPoint
}

checkgpio='^[0-9]+$'
if [[ $GPIO_CTRL =~ $checkgpio ]] ; then
	gpioctrl $GPIO_CTRL
fi

checkDetect

