#!/bin/sh -e
# watchdog-test.sh: checks the watchdog device and sysfs files
# This script checks that the given device node exists, the watchdog
# command exists, and the sysfs directory can be found.  It reports
# the current status of the watchdog.
#
# Kernel: watchdog support
# Dependencies: watchdog which

source "@TSTPLIB@"

dep_check_programs watchdog killall

DEV_NODE=$1
if [ -z "$DEV_NODE" ]; then
	error "usage: $0 <dev>"
fi

echo -n "Checking for $DEV_NODE... "
if [ -e $DEV_NODE ]; then
	echo "FOUND"
else
	error "MISSING"
fi

DEVNAME=$(basename $DEV_NODE)
SYSFS="/sys/class/watchdog/$DEVNAME"

sysfs_report() {
	local state
	state=$(cat $SYSFS/state)

	cat <<EOF
$DEVNAME sysfs status:
    Identity:  $(cat $SYSFS/identity)
      Status:  $state ($(cat $SYSFS/status))
     Timeout:  $(cat $SYSFS/timeout)
   Time left:  $(cat $SYSFS/timeleft)
  On At Boot:  $(cat $SYSFS/bootstatus)
  No Way Out:  $(cat $SYSFS/nowayout)
EOF
}

kill_watchdog_daemon() {
	echo -n "Stopping watchdog daemon... "
        killall watchdog && echo "PASS" || echo "FAIL"
}

test_wd_sysfs() {
	if [ "$(pidof watchdog)" != "" ]; then
                kill_watchdog_daemon
        fi

	echo -n "Starting watchdog daemon... "
	watchdog $DEV_NODE
	echo "PASS"

	echo -n "Waiting for timer to start... "
	sleep 4
	echo "PASS"

	t_start=$(cat $SYSFS/timeleft)

	echo -n "Waiting for timer (or system) to reset..."
	sleep 2

	while [ $(cat $SYSFS/timeleft) -lt $t_start ]; do
		echo -n "."
		sleep 1
	done
	echo " PASS"

	kill_watchdog_daemon

	echo -n "Verifying timer has stopped... "
	[ "$(cat $SYSFS/state)" = inactive ] && echo "PASS" || echo "FAIL"
}

test_wd_nosysfs() {
	if [ "$(pidof watchdog)" != "" ]; then
		kill_watchdog_daemon
	fi

	echo "Starting watchdog timer... "
	echo '' >$DEV_NODE

	sleep 2
	echo "Resetting watchdog timer... "
	echo '' >$DEV_NODE
	sleep 2

	echo -n "Stopping watchdog timer... "
	echo V >$DEV_NODE
	echo "PASS"
}

test_wd_nosysfs

echo -n "Looking for optional sysfs files ($SYSFS/state)... "
if [ -f "$SYSFS/state" ]; then
	echo "FOUND"
	sysfs_report
	test_wd_sysfs
else
	echo "MISSING"
	echo "info: watchdog sysfs tests requires " \
		"a kernel with CONFIG_WATCHDOG_SYSFS"
fi
